@@ -20,15 +20,16 @@ from fhir_cli import (
 from fhir_cli.admin import Admin
 from fhir_cli.dbt import Dbt
 from fhir_cli.fhir_resource import FhirResource, FhirValidationError
-from fhir_cli.utils.compact import dict_compact
-from fhir_cli.utils.number_print import number_print
+from utils.compact import dict_compact
+from utils.dotty import dotty_dict
+from utils.number_print import number_print
 
 CURSOR_ITERSIZE = 20
 
 
 def get_resources_from_model(
     cursor, model: str, offset: int = 0, limit: int = 100
-) -> Iterator[Tuple[int, dict]]:
+) -> Iterator[dict]:
     """get_resources_from_model looks for a fhir model file and retrieves the Fhir resources
 
     This function uses a named cursor fetching at most CURSOR_ITERSIZE rows
@@ -42,14 +43,14 @@ def get_resources_from_model(
         limit (:obj:`int`, optional): a limit for the executed query. Defaults to 100.
     """
     select_fhir_stmt = sql.SQL(
-        "SELECT id, {fhir_column_name} FROM {fhir_model} ORDER BY id LIMIT %s OFFSET %s"
+        "SELECT {fhir_column_name} FROM {fhir_model} LIMIT %s OFFSET %s"
     ).format(
         fhir_column_name=sql.Identifier(FHIR_COLUMN_NAME),
         fhir_model=sql.Identifier(model),
     )
     cursor.execute(select_fhir_stmt, (limit, offset))
     for row in cursor:
-        yield row["id"], dict_compact(row[FHIR_COLUMN_NAME])
+        yield dotty_dict(dict_compact(row[FHIR_COLUMN_NAME]))
 
 
 class Cli:
@@ -157,17 +158,18 @@ class Cli:
             # Function in order to filter ANSI escape sequences on Windows
             # see https://pypi.org/project/colorama/
             init(autoreset=True)
-            for _id, resource in get_resources_from_model(cursor, model, offset, limit):
+            for resource in get_resources_from_model(cursor, model, offset, limit):
                 fhir = FhirResource(resource)
                 number_print(repr(fhir))
                 try:
                     fhir.validate()
+                    log.info("\U0001F525 resource is valid")
                     # The message will be printed in GREEN, hence the weird sequence
                     # at the beginning and at the end
-                    log.info(f"{Fore.GREEN}✅ FHIR resource (id={_id}) is valid")
+                    log.info(f"{Fore.GREEN}✅ FHIR resource is valid")
                 except FhirValidationError as e:
                     # Same as above
-                    log.error(f"{Fore.RED}❌ FHIR resource (id={_id}) is not valid\n{e}")
+                    log.error(f"{Fore.RED}❌ FHIR resource is not valid\n{e}")
                 input("Press [Return] for the next result or [Ctrl+c] to quit")
         except ProgrammingError as e:
             conn.rollback()
